import subprocess
from gtts import gTTS
import os
def say(speak):
        tts = gTTS(speak)
        tts.save(".outputQwerthjgfr5ty4ui3j4b5fr4t6e7wuisdjhfgrty4u.mp3")
        os.system("afplay 
.outputQwerthjgfr5ty4ui3j4b5fr4t6e7wuisdjhfgrty4u.mp3$
        os.remove(".outputQwerthjgfr5ty4ui3j4b5fr4t6e7wuisdjhfgrty4u.mp3")



from setuptools import setup

setup(
    name='TalkGTTS',
    version='0.1',
    packages=['TalkGTTS'],
    url='https://github.com/Talklet123/Talk-Module',
    license='MIT',
    author='Talklet123',
    author_email='developer1234567890234@yahoo.com',
    description='Uses GTTS to make it talk.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    install_requires=[
        'gTTS>=2.4.0',
    ],
)

